@@ -67,11 +67,18 @@
 #endif
 
 // Define prototypes for nss function we're going to export (fixes GCC warnings)
-enum nss_status _nss_mdns_gethostbyname4_r(const char*, struct gaih_addrtuple**, char*, size_t, int*, int*, int32_t*);
-enum nss_status _nss_mdns_gethostbyname3_r(const char*, int, struct hostent*, char*, size_t, int*, int*, int32_t*, char**);
-enum nss_status _nss_mdns_gethostbyname2_r(const char*, int, struct hostent*, char*, size_t, int*, int*);
-enum nss_status _nss_mdns_gethostbyname_r(const char*, struct hostent*, char*, size_t, int*, int*);
-enum nss_status _nss_mdns_gethostbyaddr_r(const void*, int, int, struct hostent*, char*, size_t, int*, int*);
+enum nss_status _nss_mdns_gethostbyname4_r(const char*, struct gaih_addrtuple**,
+                                           char*, size_t, int*, int*, int32_t*);
+enum nss_status _nss_mdns_gethostbyname3_r(const char*, int, struct hostent*,
+                                           char*, size_t, int*, int*, int32_t*,
+                                           char**);
+enum nss_status _nss_mdns_gethostbyname2_r(const char*, int, struct hostent*,
+                                           char*, size_t, int*, int*);
+enum nss_status _nss_mdns_gethostbyname_r(const char*, struct hostent*, char*,
+                                          size_t, int*, int*);
+enum nss_status _nss_mdns_gethostbyaddr_r(const void*, int, int,
+                                          struct hostent*, char*, size_t, int*,
+                                          int*);
 
 static avahi_resolve_result_t do_avahi_resolve_name(int af, const char* name,
                                                     userdata_t* userdata) {
@@ -119,11 +126,9 @@ static avahi_resolve_result_t do_avahi_resolve_name(int af, const char* name,
     }
 }
 
-static enum nss_status gethostbyname_impl(
-    const char* name, int af,
-    userdata_t* u,
-    int* errnop,
-    int* h_errnop) {
+static enum nss_status gethostbyname_impl(const char* name, int af,
+                                          userdata_t* u, int* errnop,
+                                          int* h_errnop) {
 
     int name_allowed;
     FILE* mdns_allow_file = NULL;
@@ -187,39 +192,40 @@ static enum nss_status gethostbyname_impl(
     }
 }
 
-enum nss_status _nss_mdns_gethostbyname4_r(
-    const char* name,
-    struct gaih_addrtuple** pat,
-    char* buffer, size_t buflen,
-    int* errnop, int* h_errnop,
-    int32_t* ttlp) {
+enum nss_status _nss_mdns_gethostbyname4_r(const char* name,
+                                           struct gaih_addrtuple** pat,
+                                           char* buffer, size_t buflen,
+                                           int* errnop, int* h_errnop,
+                                           int32_t* ttlp) {
+
+    (void)ttlp;
 
     userdata_t u;
     buffer_t buf;
 
-    enum nss_status status = gethostbyname_impl(name, AF_UNSPEC, &u, errnop, h_errnop);
+    enum nss_status status =
+        gethostbyname_impl(name, AF_UNSPEC, &u, errnop, h_errnop);
     if (status != NSS_STATUS_SUCCESS) {
         return status;
     }
     buffer_init(&buf, buffer, buflen);
-    return convert_userdata_to_addrtuple(&u, name, pat, &buf,
-                                         errnop, h_errnop);
+    return convert_userdata_to_addrtuple(&u, name, pat, &buf, errnop, h_errnop);
 }
 
-enum nss_status _nss_mdns_gethostbyname3_r(
-    const char* name,
-    int af,
-    struct hostent* result,
-    char* buffer, size_t buflen,
-    int* errnop, int* h_errnop,
-    int32_t* ttlp,
-    char** canonp) {
+enum nss_status _nss_mdns_gethostbyname3_r(const char* name, int af,
+                                           struct hostent* result, char* buffer,
+                                           size_t buflen, int* errnop,
+                                           int* h_errnop, int32_t* ttlp,
+                                           char** canonp) {
+
+    (void)ttlp;
+    (void)canonp;
 
     buffer_t buf;
     userdata_t u;
 
-    // The interfaces for gethostbyname3_r and below do not actually support returning results
-    // for more than one address family
+    // The interfaces for gethostbyname3_r and below do not actually support
+    // returning results for more than one address family
     if (af == AF_UNSPEC) {
 #ifdef NSS_IPV6_ONLY
         af = AF_INET6;
@@ -237,55 +243,35 @@ enum nss_status _nss_mdns_gethostbyname3_r(
                                                 errnop, h_errnop);
 }
 
-enum nss_status _nss_mdns_gethostbyname2_r(
-    const char* name,
-    int af,
-    struct hostent* result,
-    char* buffer, size_t buflen,
-    int* errnop, int* h_errnop) {
+enum nss_status _nss_mdns_gethostbyname2_r(const char* name, int af,
+                                           struct hostent* result, char* buffer,
+                                           size_t buflen, int* errnop,
+                                           int* h_errnop) {
 
-    return _nss_mdns_gethostbyname3_r(
-        name,
-        af,
-        result,
-        buffer, buflen,
-        errnop, h_errnop,
-        NULL, NULL);
+    return _nss_mdns_gethostbyname3_r(name, af, result, buffer, buflen, errnop,
+                                      h_errnop, NULL, NULL);
 }
 
-enum nss_status _nss_mdns_gethostbyname_r(
-    const char* name,
-    struct hostent* result,
-    char* buffer,
-    size_t buflen,
-    int* errnop,
-    int* h_errnop) {
+enum nss_status _nss_mdns_gethostbyname_r(const char* name,
+                                          struct hostent* result, char* buffer,
+                                          size_t buflen, int* errnop,
+                                          int* h_errnop) {
 
-    return _nss_mdns_gethostbyname2_r(
-        name,
-        AF_UNSPEC,
-        result,
-        buffer,
-        buflen,
-        errnop,
-        h_errnop);
+    return _nss_mdns_gethostbyname2_r(name, AF_UNSPEC, result, buffer, buflen,
+                                      errnop, h_errnop);
 }
 
-enum nss_status _nss_mdns_gethostbyaddr_r(
-    const void* addr,
-    int len,
-    int af,
-    struct hostent* result,
-    char* buffer,
-    size_t buflen,
-    int* errnop,
-    int* h_errnop) {
+enum nss_status _nss_mdns_gethostbyaddr_r(const void* addr, int len, int af,
+                                          struct hostent* result, char* buffer,
+                                          size_t buflen, int* errnop,
+                                          int* h_errnop) {
 
     size_t address_length;
     char t[256];
 
     /* Check for address types */
-    address_length = af == AF_INET ? sizeof(ipv4_address_t) : sizeof(ipv6_address_t);
+    address_length =
+        af == AF_INET ? sizeof(ipv4_address_t) : sizeof(ipv6_address_t);
 
     if (len < (int)address_length ||
 #ifdef NSS_IPV4_ONLY
@@ -303,8 +289,10 @@ enum nss_status _nss_mdns_gethostbyaddr_r(
 
 #ifdef MDNS_MINIMAL
     /* Only query for 169.254.0.0/16 IPv4 in minimal mode */
-    if ((af == AF_INET && ((ntohl(*(const uint32_t*)addr) & 0xFFFF0000UL) != 0xA9FE0000UL)) ||
-        (af == AF_INET6 && !(((const uint8_t*)addr)[0] == 0xFE && (((const uint8_t*)addr)[1] >> 6) == 2))) {
+    if ((af == AF_INET &&
+         ((ntohl(*(const uint32_t*)addr) & 0xFFFF0000UL) != 0xA9FE0000UL)) ||
+        (af == AF_INET6 && !(((const uint8_t*)addr)[0] == 0xFE &&
+                             (((const uint8_t*)addr)[1] >> 6) == 2))) {
         *errnop = EINVAL;
         *h_errnop = NO_RECOVERY;
         return NSS_STATUS_UNAVAIL;
@@ -316,9 +304,8 @@ enum nss_status _nss_mdns_gethostbyaddr_r(
     switch (avahi_resolve_address(af, addr, t, sizeof(t))) {
     case AVAHI_RESOLVE_RESULT_SUCCESS:
         buffer_init(&buf, buffer, buflen);
-        return convert_name_and_addr_to_hostent(t, addr, address_length,
-                                                af, result,
-                                                &buf, errnop, h_errnop);
+        return convert_name_and_addr_to_hostent(t, addr, address_length, af,
+                                                result, &buf, errnop, h_errnop);
 
     case AVAHI_RESOLVE_RESULT_HOST_NOT_FOUND:
         *errnop = ETIMEDOUT;
